<TS version="2.1" language="id">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Klik kanan untuk mengedit atau label</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">O3@outlook.co.id</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">Salin alamat yang saat ini dipilih ke papan klip sistem</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp;Tutup</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Hapus alamat yang saat ini dipilih dari daftar</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Masukkan alamat atau label untuk mencari</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Ekspor data di tab saat ini ke sebuah file</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Pilih alamat tujuan pengiriman koin</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">&amp;Choose</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Ini adalah alamat Bitcoin Anda untuk mengirim pembayaran. Selalu periksa jumlah dan alamat penerima sebelum mengirim koin.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Berikut ini adalah alamat-alamat bitcoinmu untuk menerima pembayaran. Gunakan tombol 'Buat alamat penerima baru' di tab menerima untuk membuat alamat baru.
Tanda tangan hanya bisa digunakan dengan tipe alamat 'warisan'</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Copy Alamat</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Salin &amp;Label</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Daftar Alamat Ekspor</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">File yang dipisahkan koma</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Terjadi sebuah kesalahan saat mencoba menyimpan daftar alamat ke %1. Silakan coba lagi.</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Gagal Mengekspor</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation type="unfinished">Alamat</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(tidak ada label)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Dialog passphrase</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Masukan passphrase</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Passphrase baru</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Ulangi passphrase baru</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Perlihatkan passphrase</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Enkripsi dompet</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Operasi ini memerlukan passphrase dompet Anda untuk membuka dompet.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Buka dompet</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Ganti passphrase</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Konfirmasi pengenkripsian dompet</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Peringatan: Jika Anda mengenkripsi dompet Anda dan lupa kata sandi Anda, Anda akan &lt;b&gt;KEHILANGAN SEMUA BITCOIN ANDA&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Apa Anda yakin ingin mengenkripsi dompet Anda?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Dompet terenkripsi</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Masukkan passphrase baru ke dompet.&lt;br/&gt;Harap gunakan passphrase dari &lt;b&gt;sepuluh atau lebih karakter acak&lt;/b&gt;, or &lt;b&gt;delapan atau lebih kata&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Masukan passphrase lama dan passphrase baru ke dompet.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Ingat mengenkripsi dompet Anda tidak dapat sepenuhnya melindungi bitcoin Anda dari pencurian oleh malware yang menginfeksi komputer Anda.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Dompet yang akan dienkripsi</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">Dompet anda akan dienkripsi.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Dompet anda sudah dienkripsi.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">PENTING: Backup sebelumnya yang Anda buat dari file dompet Anda harus diganti dengan file dompet terenkripsi yang baru dibuat. Demi keamanan, backup file dompet sebelumnya yang tidak dienkripsi sebelumnya akan menjadi tidak berguna begitu Anda mulai menggunakan dompet terenkripsi yang baru.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Pengenkripsian dompet gagal</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Pengenkripsian dompet gagal karena kesalahan internal. Dompet Anda tidak dienkripsi.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Passphrase yang dimasukan tidak cocok.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Gagal membuka wallet</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Passphrase yang dimasukan untuk dekripsi dompet salah</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character. If this is successful, please set a new passphrase to avoid this issue in the future.</source>
        <translation type="unfinished">Frasa sandi yang dimasukkan untuk membuka dompet salah. Mengandung karakter kosong (contoh - sebuah bit kosong). Apabila frasa sandi di atur menggunakan piranti lunak sebelum versi 25.0, silahkan coba kembali dengan karakter hanya sampai dengan - tetapi tidak termasuk - karakter kosong yang pertama. Jika hal ini berhasil, silahkan atur frasa sandi yang baru untuk menghindari masalah yang sama di kemudian hari.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Kata sandi berhasil diganti.</translation>
    </message>
    <message>
        <source>Passphrase change failed</source>
        <translation type="unfinished">Penggantian frasa sandi gagal</translation>
    </message>
    <message>
        <source>The old passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character.</source>
        <translation type="unfinished">Frasa sandi lama yang dimasukkan untuk membuka dompet salah. Mengandung karakter kosong (contoh - sebuah bit kosong). Apabila frasa sandi di atur menggunakan piranti lunak sebelum versi 25.0, silahkan coba kembali  dengan karakter hanya sampai dengan - tetapi tidak termasuk - karakter kosong yang pertama.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Peringatan: Tombol Caps Lock aktif!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Di banned sampai</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">File pengaturan %1 mungkin rusak atau tidak valid.</translation>
    </message>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">Pengecualian pelarian</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">Error yang fatal telah terjadi. %1 tidak bisa berlanjut dengan selamat dan akan keluar.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Kesalahan internal</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">Terjadi kesalahan. %1 akan mencoba melanjutkan secara aman. Ini adalah bug yang tidak terduga yang dapat dilaporkan seperti penjelasan di bawah ini.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">Apakah Anda ingin mereset pengaturan ke nilai default, atau membatalkan tanpa membuat perubahan?</translation>
    </message>
    <message>
        <source>A fatal error occurred. Check that settings file is writable, or try running with -nosettings.</source>
        <extracomment>Explanatory text shown on startup when the settings file could not be written. Prompts user to check that we have the ability to write to the file. Explains that the user has the option of running without a settings file.</extracomment>
        <translation type="unfinished">Error yang fatal telah terjadi. Periksa bahwa file pengaturan dapat ditulis atau coba jalankan dengan -nosettings</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform>%n second(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform>%n minute(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform>%n hour(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform>%n day(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform>%n week(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform>%n year(s)</numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">Menghubungkan ke peers...</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Permintaan pembayaran (membuat kode QR dan bitcoin: URIs)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">Tampilkan daftar alamat dan label yang terkirim</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">Tampilkan daftar alamat dan label yang diterima</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">&amp;pilihan Command-line</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">kurang %1</translation>
    </message>
    <message>
        <source>Catching up…</source>
        <translation type="unfinished">Menyusul...</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">Blok terakhir yang diterima %1 lalu.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Transaksi setelah ini belum akan terlihat.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Terjadi sebuah kesalahan</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Peringatan</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Informasi</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Terbaru</translation>
    </message>
    <message>
        <source>Restore Wallet…</source>
        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
        <translation type="unfinished">Pulihkan Dompet…</translation>
    </message>
    <message>
        <source>Restore a wallet from a backup file</source>
        <extracomment>Status tip for Restore Wallet menu item</extracomment>
        <translation type="unfinished">Pulihkan dompet dari file cadangan</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Tutup semua dompet</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation type="unfinished">Tampilkan %1 pesan bantuan untuk mendapatkan daftar opsi baris perintah Bitcoin yang memungkinkan</translation>
    </message>
    <message>
        <source>&amp;Mask values</source>
        <translation type="unfinished">&amp;Nilai masker</translation>
    </message>
    <message>
        <source>Mask the values in the Overview tab</source>
        <translation type="unfinished">Mask nilai yang ada di tab Overview</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">wallet default</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">Tidak ada wallet tersedia</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">Data Dompet</translation>
    </message>
    <message>
        <source>Load Wallet Backup</source>
        <extracomment>The title for Restore Wallet File Windows</extracomment>
        <translation type="unfinished">Muat Pencadangan Dompet</translation>
    </message>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of pop-up window shown when the user is attempting to restore a wallet.</extracomment>
        <translation type="unfinished">Pulihkan Dompet</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">Nama Dompet</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Jendela</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">Jendela Utama</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 klien</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">Sembunyi</translation>
    </message>
    <message>
        <source>S&amp;how</source>
        <translation type="unfinished">Tampilkan</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform>%n koneksi yang aktif ke jaringan Bitcoin</numerusform>
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">Klik untuk tindakan lainnya</translation>
    </message>
    <message>
        <source>Show Peers tab</source>
        <extracomment>A context menu item. The "Peers tab" is an element of the "Node window".</extracomment>
        <translation type="unfinished">Tampilkan tab Rekan</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">nonaktifkan aktivitas jaringan</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">aktifkan aktivitas jaringan</translation>
    </message>
    <message>
        <source>Pre-syncing Headers (%1%)…</source>
        <translation type="unfinished">Pra-Singkronisasi Header (%1%)...</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Salin Perubahan</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation type="unfinished">(%1 terkunci)</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(tidak ada label)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">Bikin dompet</translation>
    </message>
    <message>
        <source>Too many external signers found</source>
        <translation type="unfinished">Terlalu banyak penanda tangan eksternal ditemukan</translation>
    </message>
</context>
<context>
    <name>LoadWalletsActivity</name>
    <message>
        <source>Load Wallets</source>
        <extracomment>Title of progress window which is displayed when wallets are being loaded.</extracomment>
        <translation type="unfinished">Tampilkan Dompet</translation>
    </message>
    <message>
        <source>Loading wallets…</source>
        <extracomment>Descriptive text of the load wallets progress window which indicates to the user that wallets are currently being loaded.</extracomment>
        <translation type="unfinished">Memuat wallet</translation>
    </message>
</context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open wallet failed</source>
        <translation type="unfinished">Gagal membuka wallet</translation>
    </message>
    <message>
        <source>Open wallet warning</source>
        <translation type="unfinished">Peringatan membuka wallet</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">wallet default</translation>
    </message>
    <message>
        <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
        <translation type="unfinished">Membuka Wallet &lt;b&gt;%1&lt;/b&gt;...</translation>
    </message>
</context>
<context>
    <name>RestoreWalletActivity</name>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of progress window which is displayed when wallets are being restored.</extracomment>
        <translation type="unfinished">Pulihkan Dompet</translation>
    </message>
    <message>
        <source>Restoring Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the restore wallets progress window which indicates to the user that wallets are currently being restored.</extracomment>
        <translation type="unfinished">Memulihkan Dompet &lt;b&gt;%1&lt;/b&gt;…</translation>
    </message>
    <message>
        <source>Restore wallet failed</source>
        <extracomment>Title of message box which is displayed when the wallet could not be restored.</extracomment>
        <translation type="unfinished">Pemulihan dompet gagal</translation>
    </message>
    <message>
        <source>Restore wallet warning</source>
        <extracomment>Title of message box which is displayed when the wallet is restored with some warning.</extracomment>
        <translation type="unfinished">Peringatan pemulihan dompet</translation>
    </message>
    <message>
        <source>Restore wallet message</source>
        <extracomment>Title of message box which is displayed when the wallet is successfully restored.</extracomment>
        <translation type="unfinished">Pesan pemulihan dompet</translation>
    </message>
</context>
<context>
    <name>WalletController</name>
    <message>
        <source>Are you sure you wish to close the wallet &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation type="unfinished">Apakah anda yakin ingin menutup dompet &lt;i&gt;%1&lt;/i&gt;?</translation>
    </message>
    <message>
        <source>Closing the wallet for too long can result in having to resync the entire chain if pruning is enabled.</source>
        <translation type="unfinished">Menutup dompet terlalu lama dapat menyebabkan harus menyinkron ulang seluruh rantai jika pemangkasan diaktifkan.</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Tutup semua dompet</translation>
    </message>
    <message>
        <source>Are you sure you wish to close all wallets?</source>
        <translation type="unfinished">Apakah anda yakin ingin menutup seluruh dompet ?</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation type="unfinished">Bikin dompet</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">Nama Dompet</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Dompet</translation>
    </message>
    <message>
        <source>Encrypt the wallet. The wallet will be encrypted with a passphrase of your choice.</source>
        <translation type="unfinished">Enkripsi dompet. Dompet akan dienkripsi dengan passphrase pilihan Anda.</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">Enkripsi Dompet</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation type="unfinished">Opsi Lanjutan</translation>
    </message>
    <message>
        <source>Disable private keys for this wallet. Wallets with private keys disabled will have no private keys and cannot have an HD seed or imported private keys. This is ideal for watch-only wallets.</source>
        <translation type="unfinished">Nonaktifkan private keys dompet ini. Dompet dengan private keys nonaktif tidak akan memiliki private keys dan tidak dapat memiliki seed HD atau private keys impor. Ini sangat ideal untuk dompet watch-only.</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation type="unfinished">Nonaktifkan private keys</translation>
    </message>
    <message>
        <source>Make a blank wallet. Blank wallets do not initially have private keys or scripts. Private keys and addresses can be imported, or an HD seed can be set, at a later time.</source>
        <translation type="unfinished">Buat dompet kosong. Dompet kosong pada awalnya tidak memiliki private keys atau skrip pribadi. Private keys dan alamat pribadi dapat diimpor, atau seed HD dapat diatur di kemudian hari.</translation>
    </message>
    <message>
        <source>Make Blank Wallet</source>
        <translation type="unfinished">Buat dompet kosong</translation>
    </message>
    <message>
        <source>Use an external signing device such as a hardware wallet. Configure the external signer script in wallet preferences first.</source>
        <translation type="unfinished">Gunakan perangkat penandatanganan eksternal seperti dompet perangkat keras. Konfigurasikan skrip penandatangan eksternal di preferensi dompet terlebih dahulu.</translation>
    </message>
    <message>
        <source>External signer</source>
        <translation type="unfinished">Penandatangan eksternal</translation>
    </message>
    <message>
        <source>Create</source>
        <translation type="unfinished">Membuat</translation>
    </message>
    <message>
        <source>Compiled without external signing support (required for external signing)</source>
        <extracomment>"External signing" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Dikompilasi tanpa dukungan penandatanganan eksternal (diperlukan untuk penandatanganan eksternal)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Ubah Alamat</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation type="unfinished">Label yang terkait dengan daftar alamat</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation type="unfinished">Alamat yang terkait dengan daftar alamat. Hanya dapat diubah untuk alamat pengirim.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Alamat</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">Alamat pengirim baru</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">Ubah alamat penerima</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">Ubah alamat pengirim</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation type="unfinished">Alamat yang dimasukkan "%1" bukanlah alamat Bitcoin yang valid.</translation>
    </message>
    <message>
        <source>Address "%1" already exists as a receiving address with label "%2" and so cannot be added as a sending address.</source>
        <translation type="unfinished">Alamat "%1" sudah ada sebagai alamat penerimaan dengan label "%2" sehingga tidak bisa ditambah sebagai alamat pengiriman.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book with label "%2".</source>
        <translation type="unfinished">Alamat "%1" yang dimasukkan sudah ada di dalam buku alamat dengan label "%2".</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Tidak dapat membuka dompet.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation type="unfinished">Pembuatan kunci baru gagal.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation type="unfinished">Sebuah data direktori baru telah dibuat.</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="unfinished">nama</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation type="unfinished">Direktori masih ada. Tambahlah %1 apabila Anda ingin membuat direktori baru disini.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation type="unfinished">Sudah ada path, dan itu bukan direktori.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation type="unfinished">Tidak bisa membuat direktori data disini.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform>%n GB ruang tersedia</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(dari %n GB yang dibutuhkan)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform>(%n GB dibutuhkan untuk rantai penuh)</numerusform>
        </translation>
    </message>
    <message>
        <source>Choose data directory</source>
        <translation type="unfinished">Pilih direktori data</translation>
    </message>
    <message>
        <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
        <translation type="unfinished">Setidaknya %1 GB data akan disimpan di direktori ini dan akan berkembang seiring berjalannya waktu.</translation>
    </message>
    <message>
        <source>Approximately %1 GB of data will be stored in this directory.</source>
        <translation type="unfinished">%1 GB data akan disimpan di direktori ini.</translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 will download and store a copy of the Bitcoin block chain.</source>
        <translation type="unfinished">%1 akan mengunduh dan menyimpan salinan rantai blok Bitcoin.</translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation type="unfinished">Dompet juga akan disimpan di direktori ini.</translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" cannot be created.</source>
        <translation type="unfinished">Kesalahan: Direktori data "%1" tidak dapat dibuat.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Terjadi sebuah kesalahan</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">Selamat Datang</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation type="unfinished">Selamat Datang di %1.</translation>
    </message>
    <message>
        <source>As this is the first time the program is launched, you can choose where %1 will store its data.</source>
        <translation type="unfinished">Karena ini adalah pertama kalinya program dijalankan, Anda dapat memilih lokasi %1 akan menyimpan data.</translation>
    </message>
    <message>
        <source>Limit block chain storage to</source>
        <translation type="unfinished">Batasi penyimpanan rantai blok menjadi </translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain. It is faster to download the full chain first and prune it later. Disables some advanced features.</source>
        <translation type="unfinished">Mengembalikan pengaturan perlu mengunduh ulang seluruh blockchain. Lebih cepat mengunduh rantai penuh terlebih dahulu dan memangkasnya kemudian. Menonaktifkan beberapa fitur lanjutan.</translation>
    </message>
    <message>
        <source> GB</source>
        <translation type="unfinished">GB</translation>
    </message>
    <message>
        <source>This initial synchronisation is very demanding, and may expose hardware problems with your computer that had previously gone unnoticed. Each time you run %1, it will continue downloading where it left off.</source>
        <translation type="unfinished">Sinkronisasi awal sangat berat dan mungkin akan menunjukkan permasalahan pada perangkat keras komputer Anda yang sebelumnya tidak tampak. Setiap kali Anda menjalankan %1, aplikasi ini akan melanjutkan pengunduhan dari posisi terakhir.</translation>
    </message>
    <message>
        <source>When you click OK, %1 will begin to download and process the full %4 block chain (%2 GB) starting with the earliest transactions in %3 when %4 initially launched.</source>
        <translation type="unfinished">Ketika Anda mengklik OK, %1 akan mulai mengunduh dan memproses %4 block chain penuh (%2 GB) dimulai dari transaksi-transaksi awal di %3 saat %4 diluncurkan pertama kali.</translation>
    </message>
    <message>
        <source>If you have chosen to limit block chain storage (pruning), the historical data must still be downloaded and processed, but will be deleted afterward to keep your disk usage low.</source>
        <translation type="unfinished">Apabila Anda memilih untuk membatasi penyimpanan block chain (pruning), data historis tetap akan diunduh dan diproses. Namun, data akan dihapus setelahnya untuk menjaga pemakaian disk agar tetap sedikit.</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation type="unfinished">Gunakan direktori data default.</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation type="unfinished">Gunakan direktori pilihan Anda:</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">versi</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished">Tentang %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation type="unfinished">Pilihan Command-line</translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation type="unfinished">Kamu tidak dapat mematikan komputer sebelum jendela ini tertutup sendiri.</translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Formulir</translation>
    </message>
    <message>
        <source>Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the bitcoin network, as detailed below.</source>
        <translation type="unfinished">Transaksi-transaksi terkini mungkin belum terlihat dan oleh karenanya, saldo dompet Anda mungkin tidak tepat. Informasi ini akan akurat ketika dompet Anda tersinkronisasi dengan jaringan Bitcoin, seperti rincian berikut.</translation>
    </message>
    <message>
        <source>Attempting to spend bitcoins that are affected by not-yet-displayed transactions will not be accepted by the network.</source>
        <translation type="unfinished">Usaha untuk menggunakan bitcoin yang dipengaruhi oleh transaksi yang belum terlihat tidak akan diterima oleh jaringan.</translation>
    </message>
    <message>
        <source>Number of blocks left</source>
        <translation type="unfinished">Jumlah blok tersisa</translation>
    </message>
    <message>
        <source>Unknown…</source>
        <translation type="unfinished">Tidak diketahui...</translation>
    </message>
    <message>
        <source>calculating…</source>
        <translation type="unfinished">menghitung...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Waktu blok terakhir</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation type="unfinished">Perkembangan</translation>
    </message>
    <message>
        <source>Progress increase per hour</source>
        <translation type="unfinished">Peningkatan perkembangan per jam</translation>
    </message>
    <message>
        <source>Estimated time left until synced</source>
        <translation type="unfinished">Estimasi waktu tersisa sampai tersinkronisasi</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">Sembunyikan</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="unfinished">Keluar</translation>
    </message>
    <message>
        <source>%1 is currently syncing.  It will download headers and blocks from peers and validate them until reaching the tip of the block chain.</source>
        <translation type="unfinished">%1 menyinkronkan. Program ini akan mengunduh header dan blok dari rekan dan memvalidasi sampai blok terbaru.</translation>
    </message>
    <message>
        <source>Unknown. Syncing Headers (%1, %2%)…</source>
        <translation type="unfinished">Tidak diketahui. Sinkronisasi Header (%1, %2%)...</translation>
    </message>
    <message>
        <source>Unknown. Pre-syncing Headers (%1, %2%)…</source>
        <translation type="unfinished">Tidak diketahui. Pra-sinkronisasi Header (%1, %2%)...</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Full path to a %1 compatible script (e.g. C:\Downloads\hwi.exe or /Users/you/Downloads/hwi.py). Beware: malware can steal your coins!</source>
        <translation type="unfinished">Alamat lengkap untuk script kompatibel %1 (Contoh C:\Downloads\hwi.exe atau /Users/you/Downloads/hwi.py). HATI-HATI: piranti lunak jahat dapat mencuri koin Anda!</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation type="unfinished">Alamat IP proxy (cth. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Shows if the supplied default SOCKS5 proxy is used to reach peers via this network type.</source>
        <translation type="unfinished">Perlihatkan apabila proxy SOCKS5 default digunakan untuk berhungan dengan orang lain lewat tipe jaringan ini.</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Exit in the menu.</source>
        <translation type="unfinished">Minimalisasi aplikasi ketika jendela ditutup. Ketika pilihan ini dipilih, aplikasi akan menutup seluruhnya jika anda memilih Keluar di menu yang tersedia.</translation>
    </message>
    <message>
        <source>Options set in this dialog are overridden by the command line:</source>
        <translation type="unfinished">Set opsi pengaturan pada jendela dialog ini tertutup oleh baris perintah:</translation>
    </message>
    <message>
        <source>Open the %1 configuration file from the working directory.</source>
        <translation type="unfinished">Buka file konfigurasi %1 dari direktori kerja.</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation type="unfinished">Buka Berkas Konfigurasi</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation type="unfinished">Kembalikan semua pengaturan ke awal.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation type="unfinished">&amp;Reset Pilihan</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;Jaringan</translation>
    </message>
    <message>
        <source>Prune &amp;block storage to</source>
        <translation type="unfinished">Prune &amp;ruang penyimpan block ke</translation>
    </message>
    <message>
        <source>Reverting this setting requires re-downloading the entire blockchain.</source>
        <translation type="unfinished">Mengembalikan pengaturan ini membutuhkan pengunduhan seluruh blockchain lagi.</translation>
    </message>
    <message>
        <source>Maximum database cache size. A larger cache can contribute to faster sync, after which the benefit is less pronounced for most use cases. Lowering the cache size will reduce memory usage. Unused mempool memory is shared for this cache.</source>
        <extracomment>Tooltip text for Options window setting that sets the size of the database cache. Explains the corresponding effects of increasing/decreasing this value.</extracomment>
        <translation type="unfinished">Ukuran maksimum cache database. Semakin besar cache membuat proses sync lebih cepat, setelah itu manfaatnya berkurang bagi sebagian besar pengguna. Mengurangi ukuran cache dapat  menurunkan penggunaan memory yang juga digunakan untuk cache ini.</translation>
    </message>
    <message>
        <source>Set the number of script verification threads. Negative values correspond to the number of cores you want to leave free to the system.</source>
        <extracomment>Tooltip text for Options window setting that sets the number of script verification threads. Explains that negative values mean to leave these many cores free to the system.</extracomment>
        <translation type="unfinished">Set nomor thread script verifikasi. Nilai negatif sesuai dengan core yang tidak ingin digunakan di dalam system.</translation>
    </message>
    <message>
        <source>This allows you or a third party tool to communicate with the node through command-line and JSON-RPC commands.</source>
        <extracomment>Tooltip text for Options window setting that enables the RPC server.</extracomment>
        <translation type="unfinished">Ini memungkinkan Anda atau alat pihak ketiga untuk berkomunikasi dengan node melalui perintah baris perintah dan JSON-RPC.</translation>
    </message>
    <message>
        <source>Enable R&amp;PC server</source>
        <extracomment>An Options window setting to enable the RPC server.</extracomment>
        <translation type="unfinished">Aktifkan server R&amp;PC</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">D&amp;ompet</translation>
    </message>
    <message>
        <source>Whether to set subtract fee from amount as default or not.</source>
        <extracomment>Tooltip text for Options window setting that sets subtracting the fee from a sending amount as default.</extracomment>
        <translation type="unfinished">Apakah akan menetapkan biaya pengurangan dari jumlah sebagai default atau tidak.</translation>
    </message>
    <message>
        <source>Subtract &amp;fee from amount by default</source>
        <extracomment>An Options window setting to set subtracting the fee from a sending amount as default.</extracomment>
        <translation type="unfinished">Kurangi biaya dari jumlah secara default</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation type="unfinished">Ahli</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation type="unfinished">Perbolehkan fitur &amp;pengaturan koin</translation>
    </message>
    <message>
        <source>If you disable the spending of unconfirmed change, the change from a transaction cannot be used until that transaction has at least one confirmation. This also affects how your balance is computed.</source>
        <translation type="unfinished">Jika Anda menonaktifkan perubahan saldo untuk transaksi yang belum dikonfirmasi, perubahan dari transaksi tidak dapat dilakukan sampai transaksi memiliki setidaknya satu konfirmasi. Hal ini juga mempengaruhi bagaimana saldo Anda dihitung.</translation>
    </message>
    <message>
        <source>&amp;Spend unconfirmed change</source>
        <translation type="unfinished">&amp;Perubahan saldo untuk transaksi yang belum dikonfirmasi</translation>
    </message>
    <message>
        <source>Enable &amp;PSBT controls</source>
        <extracomment>An options window setting to enable PSBT controls.</extracomment>
        <translation type="unfinished">Aktifkan kontrol &amp;PSBT</translation>
    </message>
    <message>
        <source>Whether to show PSBT controls.</source>
        <extracomment>Tooltip text for options window setting that enables PSBT controls.</extracomment>
        <translation type="unfinished">Apakah akan menampilkan kontrol PSBT.</translation>
    </message>
    <message>
        <source>External Signer (e.g. hardware wallet)</source>
        <translation type="unfinished">Penandatangan eksternal (seperti dompet perangkat keras)</translation>
    </message>
    <message>
        <source>&amp;External signer script path</source>
        <translation type="unfinished">&amp;Jalur skrip penanda tangan eksternal</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Jendela</translation>
    </message>
    <message>
        <source>Compiled without external signing support (required for external signing)</source>
        <extracomment>"External signing" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Dikompilasi tanpa dukungan penandatanganan eksternal (diperlukan untuk penandatanganan eksternal)</translation>
    </message>
    <message>
        <source>Current settings will be backed up at "%1".</source>
        <extracomment>Text explaining to the user that the client's current settings will be backed up at a specific location. %1 is a stand-in argument for the backup location's path.</extracomment>
        <translation type="unfinished">Pengaturan saat ini akan dicadangkan di "%1".</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Terjadi sebuah kesalahan</translation>
    </message>
    </context>
<context>
    <name>OptionsModel</name>
    <message>
        <source>Could not read setting "%1", %2.</source>
        <translation type="unfinished">Tidak dapat membaca setelan "%1", %2.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Formulir</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>PSBT Operations</source>
        <translation type="unfinished">Operasi PBST</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Age</source>
        <extracomment>Title of Peers Table column which indicates the duration (length of time) since the peer connection started.</extracomment>
        <translation type="unfinished">Umur</translation>
    </message>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Alamat</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Whether we relay transactions to this peer.</source>
        <translation type="unfinished">Apakah kita merelay transaksi ke peer ini.</translation>
    </message>
    <message>
        <source>Transaction Relay</source>
        <translation type="unfinished">Relay Transaksi</translation>
    </message>
    <message>
        <source>The total number of addresses received from this peer that were processed (excludes addresses that were dropped due to rate-limiting).</source>
        <extracomment>Tooltip text for the Addresses Processed field in the peer details area, which displays the total number of addresses received from this peer that were processed (excludes addresses that were dropped due to rate-limiting).</extracomment>
        <translation type="unfinished">Jumlah total alamat yang diterima dari rekan ini yang diproses (tidak termasuk alamat yang dihapus karena pembatasan tarif).</translation>
    </message>
    <message>
        <source>The total number of addresses received from this peer that were dropped (not processed) due to rate-limiting.</source>
        <extracomment>Tooltip text for the Addresses Rate-Limited field in the peer details area, which displays the total number of addresses received from this peer that were dropped (not processed) due to rate-limiting.</extracomment>
        <translation type="unfinished">Jumlah total alamat yang diterima dari rekan ini yang dihapus (tidak diproses) karena pembatasan tarif.</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Waktu blok terakhir</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Not recommended due to higher fees and less protection against typos.</source>
        <translation type="unfinished">Tidak direkomendasikan karena tingginya biaya dan kurang perlindungan terhadap salah ketik.</translation>
    </message>
    <message>
        <source>Generates an address compatible with older wallets.</source>
        <translation type="unfinished">Menghasilkan sebuah alamat yang kompatibel dengan dompet lama.</translation>
    </message>
    <message>
        <source>Generates a native segwit address (BIP-173). Some old wallets don't support it.</source>
        <translation type="unfinished">Menghasilkan alamat segwit asli (BIP-173). Beberapa dompet lama tidak mendukungnya. </translation>
    </message>
    <message>
        <source>Bech32m (BIP-350) is an upgrade to Bech32, wallet support is still limited.</source>
        <translation type="unfinished">Bech32m (BIP-350) adalah peningkatan terhadap Bech32, dukungan dompet masih terbatas.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Tidak dapat membuka dompet.</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(tidak ada label)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Hide</source>
        <translation type="unfinished">Sembunyikan</translation>
    </message>
    <message>
        <source>Unsigned Transaction</source>
        <comment>PSBT copied</comment>
        <extracomment>Caption of "PSBT has been copied" messagebox</extracomment>
        <translation type="unfinished">Transaksi tidak Tertandatangani</translation>
    </message>
    <message>
        <source>The PSBT has been copied to the clipboard. You can also save it.</source>
        <translation type="unfinished">PSBT telah disalin ke clipboard. Anda juga dapat menyimpannya.</translation>
    </message>
    <message>
        <source>PSBT saved to disk</source>
        <translation type="unfinished">PSBT disimpan ke disk.</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(tidak ada label)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>0/unconfirmed, in memory pool</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents an unconfirmed transaction that is in the memory pool.</extracomment>
        <translation type="unfinished">0/belum dikonfirmasi, di kumpulan memori</translation>
    </message>
    <message>
        <source>0/unconfirmed, not in memory pool</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents an unconfirmed transaction that is not in the memory pool.</extracomment>
        <translation type="unfinished">0/belum dikonfirmasi, tidak di kumpulan memori</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform>matures in %n more block(s)</numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(tidak ada label)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">File yang dipisahkan koma</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Alamat</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Gagal Mengekspor</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">Terjadi sebuah kesalahan</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Copied to clipboard</source>
        <comment>Fee-bump PSBT saved</comment>
        <translation type="unfinished">Disalin ke clipboard</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">wallet default</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Ekspor data di tab saat ini ke sebuah file</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">Data Dompet</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>%s request to listen on port %u. This port is considered "bad" and thus it is unlikely that any peer will connect to it. See doc/p2p-bad-ports.md for details and a full list.</source>
        <translation type="unfinished">%s meminta mendengarkan di port %u. Port ini dianggap "buruk" dan oleh karena itu tidak mungkin peer lain akan terhubung kesini. Lihat doc/p2p-bad-ports.md untuk detail dan daftar lengkap.</translation>
    </message>
    <message>
        <source>Disk space for %s may not accommodate the block files. Approximately %u GB of data will be stored in this directory.</source>
        <translation type="unfinished">Ruang penyimpanan %s mungkin tidak mengakomodasi berkas blok. Perkiraan %u GB data akan disimpan di direktori ini.</translation>
    </message>
    <message>
        <source>Error loading wallet. Wallet requires blocks to be downloaded, and software does not currently support loading wallets while blocks are being downloaded out of order when using assumeutxo snapshots. Wallet should be able to load successfully after node sync reaches height %s</source>
        <translation type="unfinished">Eror saat membuka dompet. Dompet memerlukan blok untuk diunduh, dan piranti lunak saat ini tidak mendukung membuka dompet saat blok yang diunduh tidak tersedia saat memakai snapshot utxo yang diasumsikan. Dompet seharusnya dapat berhasil dibuka sesudah sinkronisasi node mencapai ketinggian %s</translation>
    </message>
    <message>
        <source>Error: Unable to produce descriptors for this legacy wallet. Make sure to provide the wallet's passphrase if it is encrypted.</source>
        <translation type="unfinished">Eror: Tidak dapat membuat deskriptor untuk dompet legasi ini. Pastikan untuk menyertakan frasa sandi dompet apabila dienkripsi.</translation>
    </message>
    <message>
        <source>Prune mode is incompatible with -reindex-chainstate. Use full -reindex instead.</source>
        <translation type="unfinished">Mode pangkas tidak kompatibel dengan -reindex-chainstate. Gunakan full -reindex sebagai gantinya.</translation>
    </message>
    <message>
        <source>This is the maximum transaction fee you pay (in addition to the normal fee) to prioritize partial spend avoidance over regular coin selection.</source>
        <translation type="unfinished">Ini adalah biaya transaksi maksimum yang Anda bayarkan (selain biaya normal) untuk memprioritaskan penghindaran pengeluaran sebagian daripada pemilihan koin biasa.</translation>
    </message>
    <message>
        <source>Unsupported chainstate database format found. Please restart with -reindex-chainstate. This will rebuild the chainstate database.</source>
        <translation type="unfinished">Ditemukan format database chainstate yang tidak didukung. Silakan mulai ulang dengan -reindex-chainstate. Ini akan membangun kembali database chainstate.</translation>
    </message>
    <message>
        <source>Wallet created successfully. The legacy wallet type is being deprecated and support for creating and opening legacy wallets will be removed in the future.</source>
        <translation type="unfinished">Dompet berhasil dibuat. Jenis dompet lama tidak digunakan lagi dan dukungan untuk membuat dan membuka dompet lama akan dihapus di masa mendatang.</translation>
    </message>
    <message>
        <source>Error: Address book data in wallet cannot be identified to belong to migrated wallets</source>
        <translation type="unfinished">Kesalahan: Data buku alamat di dompet tidak dapat diidentifikasi sebagai dompet yang dimigrasikan</translation>
    </message>
    <message>
        <source>Error: Duplicate descriptors created during migration. Your wallet may be corrupted.</source>
        <translation type="unfinished">Kesalahan: Deskriptor duplikat dibuat selama migrasi. Dompet Anda mungkin rusak.</translation>
    </message>
    <message>
        <source>Error: Transaction %s in wallet cannot be identified to belong to migrated wallets</source>
        <translation type="unfinished">Kesalahan: %s transaksi di dompet tidak dapat diidentifikasi sebagai dompet yang dimigrasikan</translation>
    </message>
    <message>
        <source>Incompatible options: -dnsseed=1 was explicitly specified, but -onlynet forbids connections to IPv4/IPv6</source>
        <translation type="unfinished">Opsi yang tidak kompatibel: -dnsseed=1 secara eksplisit ditentukan, tetapi -onlynet melarang koneksi ke IPv4/IPv6</translation>
    </message>
    <message>
        <source>Outbound connections restricted to CJDNS (-onlynet=cjdns) but -cjdnsreachable is not provided</source>
        <translation type="unfinished">Koneksi keluar dibatasi untuk CJDNS (-onlynet=cjdns) tetapi -cjdnsreachable tidak disertakan</translation>
    </message>
    <message>
        <source>Outbound connections restricted to Tor (-onlynet=onion) but the proxy for reaching the Tor network is explicitly forbidden: -onion=0</source>
        <translation type="unfinished">Koneksi keluar dibatasi untuk Tor (-onlynet=onion) tetapi proxy untuk mencapai jaringan Tor secara eksplisit dilarang: -onion=0</translation>
    </message>
    <message>
        <source>Outbound connections restricted to Tor (-onlynet=onion) but the proxy for reaching the Tor network is not provided: none of -proxy, -onion or -listenonion is given</source>
        <translation type="unfinished">Koneksi keluar dibatasi untuk Tor (-onlynet=onion) tetapi proxy untuk mencapai jaringan Tor tidak disediakan: tidak ada -proxy, -onion atau -listenonion yang diberikan</translation>
    </message>
    <message>
        <source>Outbound connections restricted to i2p (-onlynet=i2p) but -i2psam is not provided</source>
        <translation type="unfinished">Koneksi keluar dibatasi untuk i2p (-onlynet=i2p) tetapi -i2psam tidak disertakan</translation>
    </message>
    <message>
        <source>The inputs size exceeds the maximum weight. Please try sending a smaller amount or manually consolidating your wallet's UTXOs</source>
        <translation type="unfinished">Ukuran input melebihi batas maksimal berat. Silahkan coba kirim jumlah yang lebih kecil atau mengkonsolidasi secara manual UTXO dompet Anda</translation>
    </message>
    <message>
        <source>The preselected coins total amount does not cover the transaction target. Please allow other inputs to be automatically selected or include more coins manually</source>
        <translation type="unfinished">Jumlah total koin yang dipilih tidak menutupi transaksi target. Silahkan izinkan input yang lain untuk secara otomatis dipilih atau masukkan lebih banyak koin secara manual.</translation>
    </message>
    <message>
        <source>Unexpected legacy entry in descriptor wallet found. Loading wallet %s

The wallet might have been tampered with or created with malicious intent.
</source>
        <translation type="unfinished">Masukan yang tidak diharapkan dalam deskriptor dompet legasi telah ditemukan. Memuat dompet %s

Dompet kemungkinan telah dibobol dengan atau dibuat dengan tujuan jahat.
</translation>
    </message>
    <message>
        <source>Unrecognized descriptor found. Loading wallet %s

The wallet might had been created on a newer version.
Please try running the latest software version.
</source>
        <translation type="unfinished">Ditemukan deskriptor yang tidak dikenal. Memuat dompet %s

Dompet mungkin telah dibuat pada versi yang lebih baru.
Silakan coba jalankan versi perangkat lunak terbaru.
</translation>
    </message>
    <message>
        <source>
Unable to cleanup failed migration</source>
        <translation type="unfinished">
Tidak dapat membersihkan migrasi yang gagal</translation>
    </message>
    <message>
        <source>
Unable to restore backup of wallet.</source>
        <translation type="unfinished">
Tidak dapat memulihkan cadangan dompet..</translation>
    </message>
    <message>
        <source>Error: Cannot extract destination from the generated scriptpubkey</source>
        <translation type="unfinished">Eror: Tidak dapat mengekstrak destinasi dari scriptpubkey yang dibuat</translation>
    </message>
    <message>
        <source>Error: Could not add watchonly tx to watchonly wallet</source>
        <translation type="unfinished">Kesalahan: Tidak dapat menambahkan watchonly tx ke dompet watchonly</translation>
    </message>
    <message>
        <source>Error: Could not delete watchonly transactions</source>
        <translation type="unfinished">Kesalahan: Tidak dapat menghapus transaksi hanya menonton</translation>
    </message>
    <message>
        <source>Error: Failed to create new watchonly wallet</source>
        <translation type="unfinished">Kesalahan: Gagal membuat dompet baru yang hanya dilihat</translation>
    </message>
    <message>
        <source>Error: Not all watchonly txs could be deleted</source>
        <translation type="unfinished">Kesalahan: Tidak semua txs watchonly dapat dihapus</translation>
    </message>
    <message>
        <source>Error: This wallet already uses SQLite</source>
        <translation type="unfinished">Kesalahan: Dompet ini sudah menggunakan SQLite</translation>
    </message>
    <message>
        <source>Error: This wallet is already a descriptor wallet</source>
        <translation type="unfinished">Kesalahan: Dompet ini sudah menjadi dompet deskriptor</translation>
    </message>
    <message>
        <source>Error: Unable to begin reading all records in the database</source>
        <translation type="unfinished">Kesalahan: Tidak dapat mulai membaca semua catatan dalam database</translation>
    </message>
    <message>
        <source>Error: Unable to make a backup of your wallet</source>
        <translation type="unfinished">Kesalahan: Tidak dapat membuat cadangan dompet Anda</translation>
    </message>
    <message>
        <source>Error: Unable to read all records in the database</source>
        <translation type="unfinished">Kesalahan: Tidak dapat membaca semua catatan dalam database</translation>
    </message>
    <message>
        <source>Error: Unable to remove watchonly address book data</source>
        <translation type="unfinished">Kesalahan: Tidak dapat menghapus data buku alamat yang hanya dilihat</translation>
    </message>
    <message>
        <source>Insufficient dbcache for block verification</source>
        <translation type="unfinished">Kekurangan dbcache untuk verifikasi blok</translation>
    </message>
    <message>
        <source>Invalid port specified in %s: '%s'</source>
        <translation type="unfinished">Port tidak valid dalam %s:'%s'</translation>
    </message>
    <message>
        <source>Invalid pre-selected input %s</source>
        <translation type="unfinished">Input yang dipilih tidak valid %s</translation>
    </message>
    <message>
        <source>Listening for incoming connections failed (listen returned error %s)</source>
        <translation type="unfinished">Mendengarkan koneksi masuk gagal (mendengarkan kesalahan yang dikembalikan %s)</translation>
    </message>
    <message>
        <source>Not found pre-selected input %s</source>
        <translation type="unfinished">Tidak ditemukan input yang dipilih %s</translation>
    </message>
    <message>
        <source>Not solvable pre-selected input %s</source>
        <translation type="unfinished">Tidak dapat diselesaikan input yang dipilih %s</translation>
    </message>
    <message>
        <source>Unable to allocate memory for -maxsigcachesize: '%s' MiB</source>
        <translation type="unfinished">Tidak dapat mengalokasikan memori untuk -maxsigcachesize: '%s' MiB</translation>
    </message>
    <message>
        <source>Unable to find UTXO for external input</source>
        <translation type="unfinished">Tidak dapat menemukan UTXO untuk input eksternal</translation>
    </message>
    <message>
        <source>Unable to unload the wallet before migrating</source>
        <translation type="unfinished">Tidak dapat membongkar dompet sebelum bermigrasi</translation>
    </message>
    </context>
</TS>